Commit: 21cd575e88a253c14348c68b6b2def8289fcfd76
Author: Bastien Montagne
Date:   Wed Mar 20 10:28:46 2019 +0100
Branches: master
https://developer.blender.org/rB21cd575e88a253c14348c68b6b2def8289fcfd76

Fix (unreported) Copy/Paste: orig object being instantiated in active 
collection on pasting.

When copy/pasting an object in same .blend file, orig object would be
instantiated into the active collection when pasting, along with the
content of the paste. Was missing a clear of LIB_TAG_DOIT on objects...

Found while investigating T61670.

===================================================================

M       source/blender/blenloader/intern/readfile.c

===================================================================

diff --git a/source/blender/blenloader/intern/readfile.c 
b/source/blender/blenloader/intern/readfile.c
index b8131c8abbb..221125fefbe 100644
--- a/source/blender/blenloader/intern/readfile.c
+++ b/source/blender/blenloader/intern/readfile.c
@@ -11106,7 +11106,8 @@ static Main *library_link_begin(Main *mainvar, FileData 
**fd, const char *filepa
 
        (*fd)->mainlist = MEM_callocN(sizeof(ListBase), "FileData.mainlist");
 
-       /* clear for collection instantiating tag */
+       /* clear for objects and collections instantiating tag */
+       BKE_main_id_tag_listbase(&(mainvar->objects), LIB_TAG_DOIT, false);
        BKE_main_id_tag_listbase(&(mainvar->collections), LIB_TAG_DOIT, false);
 
        /* make mains */

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
https://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to